@@ -1,6 +1,8 @@
 import asyncio
 import logging
+import os
 from enum import Enum
+from pathlib import Path
 from typing import List, Optional, Tuple
 
 import pandas as pd
@@ -12,7 +14,11 @@ from toucan_connectors.oauth2_connector.oauth2connector import (
     OAuth2Connector,
     OAuth2ConnectorConfig,
 )
-from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
+from toucan_connectors.toucan_connector import (
+    ConnectorSecretsForm,
+    ToucanConnector,
+    ToucanDataSource,
+)
 
 from .constants import MAX_RUNS, PER_PAGE
 from .helpers import DICTIONARY_OF_FORMATTERS, build_df, build_empty_df
@@ -117,6 +123,13 @@ class AircallConnector(ToucanConnector):
     auth_flow_id: Optional[str]
     data_source_model: AircallDataSource
 
+    @staticmethod
+    def get_connector_secrets_form() -> ConnectorSecretsForm:
+        return ConnectorSecretsForm(
+            documentation_md=(Path(os.path.dirname(__file__)) / 'doc.md').read_text(),
+            secrets_schema=OAuth2ConnectorConfig.schema(),
+        )
+
     def __init__(self, **kwargs):
         super().__init__(
             **{k: v for k, v in kwargs.items() if k not in OAuth2Connector.init_params}
@@ -127,10 +140,10 @@ class AircallConnector(ToucanConnector):
             scope=SCOPE,
             token_url=TOKEN_URL,
             secrets_keeper=kwargs['secrets_keeper'],
+            redirect_uri=kwargs['redirect_uri'],
             config=OAuth2ConnectorConfig(
                 client_id=kwargs['client_id'],
                 client_secret=kwargs['client_secret'],
-                redirect_uri=kwargs['redirect_uri'],
             ),
         )
 
